@@ -47,13 +47,13 @@
 }
 
 - (void)update:sender
-{   id          g = sender;
+{   VGraphic    *g = sender;
     Document    *doc = [[self view] document];
 
     /* multiple graphics ? (line, curve, arc, rectangle, polyline, path) */
     if ([g isMemberOfClass:[VCrosshairs class]])
-    {   int	i, l, cnt;
-        id	slayList = [[self view] slayList];
+    {   int     i, l, cnt;
+        NSArray *slayList = [[self view] slayList];
 
         /* set width of all objects */
         cnt = [slayList count];
@@ -137,7 +137,7 @@
         v = [widthSlider floatValue];
     else if ([sender isKindOfClass:[NSButton class]])
     {
-        switch ([sender tag])
+        switch ([(NSButton*)sender tag])
         {
             case BUTTONLEFT:	v -= ((control) ? 1.0 : 0.1); break;
             case BUTTONRIGHT:	v += ((control) ? 1.0 : 0.1);
