@@ -177,15 +177,19 @@
 - (void)recordDetail
 {
     oldBounds.size = [graphic size];
+    oldWidth       = [graphic width];
 }
 - (void)undoDetail
 {
     newBounds.size = [graphic size];
     [graphic setSize:oldBounds.size];
+    newWidth       = [graphic width];
+    [graphic setWidth:oldWidth];
 }
 - (void)redoDetail
 {
     [graphic setSize:newBounds.size];
+    [graphic setWidth:newWidth];
 }
 @end
 
